@@ -1,3 +1,4 @@
+import os
 from subprocess import Popen, DEVNULL
 
 from devdeck_core.controls.deck_control import DeckControl
@@ -7,7 +8,7 @@ class CommandControl(DeckControl):
     def initialize(self):
         with self.deck_context() as context:
             with context.renderer() as r:
-                r.image(self.settings['icon']).end()
+                r.image(os.path.expanduser(self.settings['icon'])).end()
 
     def pressed(self):
         Popen(self.settings['command'], stdout=DEVNULL, stderr=DEVNULL)
